function varargout = Guardar_ensayosim(varargin)
% GUARDAR_ENSAYOSIM M-file for Guardar_ensayosim.fig
%      GUARDAR_ENSAYOSIM, by itself, creates a new GUARDAR_ENSAYOSIM or raises the existing
%      singleton*.
%
%      H = GUARDAR_ENSAYOSIM returns the handle to a new GUARDAR_ENSAYOSIM or the handle to
%      the existing singleton*.
%
%      GUARDAR_ENSAYOSIM('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GUARDAR_ENSAYOSIM.M with the given input arguments.
%
%      GUARDAR_ENSAYOSIM('Property','Value',...) creates a new GUARDAR_ENSAYOSIM or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Guardar_ensayosim_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Guardar_ensayosim_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help Guardar_ensayosim

% Last Modified by GUIDE v2.5 09-Dec-2004 20:04:21

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Guardar_ensayosim_OpeningFcn, ...
                   'gui_OutputFcn',  @Guardar_ensayosim_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Guardar_ensayosim is made visible.
function Guardar_ensayosim_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Guardar_ensayosim (see VARARGIN)

% Choose default command line output for Guardar_ensayosim
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Guardar_ensayosim wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Guardar_ensayosim_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes during object creation, after setting all properties.
function edit1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function edit1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1 as text
%        str2double(get(hObject,'String')) returns contents of edit1 as a double


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if get(handles.edit1,'string')==' '
    errordlg(lasterr,'Campo Archivos vacio','modal');
    return;
end
%uistack('Base','top');
datos=get(handles.edit1,'string');
if isdir('historicos')
    cd c:\matlab6p5\work\historicos;
    assignin('base','datos',datos);
    evalin('base','save(datos)');
    cd .. ;
else
    mkdir('historicos');
    cd c:\matlab6p5\work\historicos;
    assignin('base','datos',datos);
    evalin('base','save(datos)');
    cd .. ;
end
close('mimicosim');
bdclose('all');
close('Guardar_ensayosim');
run('solarsim');

% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

close('mimicosim');
bdclose('all');
close('Guardar_ensayosim');
run('solarsim');
